@@ -1,6 +1,6 @@
 
 package Importer::Zim;
-$Importer::Zim::VERSION = '0.3.0';
+$Importer::Zim::VERSION = '0.4.0';
 # ABSTRACT: Import functions à la Invader Zim
 
 use 5.018;
@@ -12,7 +12,7 @@ sub import {
 }
 
 my %MIN_VERSION = do {
-    my %v = ( '+Lexical' => '0.5.0', );
+    my %v = ( '+Lexical' => '0.6.0', );
     /^\+/ and $v{ backend_class($_) } = $v{$_} for keys %v;
     %v;
 };
@@ -25,7 +25,7 @@ sub backend_class {
 }
 
 sub backend {
-    my $how = ( ref $_[2] ? $_[2]->{-how} : undef ) // '+Lexical';
+    my $how = ( ref $_[2] eq 'HASH' ? $_[2]->{-how} : undef ) // '+Lexical';
     my $backend = backend_class($how);
     my @version
       = exists $MIN_VERSION{$backend} ? ( $MIN_VERSION{$backend} ) : ();
@@ -65,7 +65,7 @@ sub backend {
 #pod By default, L<Importer::Zim> looks at package variables
 #pod C<@EXPORT>, C<@EXPORT_OK> and C<%EXPORT_TAGS> to decide
 #pod what are exportable subroutines. It tries its best to implement
-#pod a behavior akin to L<Exporter> without the corresponding package polution.
+#pod a behavior akin to L<Exporter> without the corresponding namespace pollution.
 #pod
 #pod =head1 METHODS
 #pod
@@ -96,7 +96,7 @@ Importer::Zim - Import functions à la Invader Zim
 
 =head1 VERSION
 
-version 0.3.0
+version 0.4.0
 
 =head1 SYNOPSIS
 
@@ -127,7 +127,7 @@ as soon the lexical scope ends.
 By default, L<Importer::Zim> looks at package variables
 C<@EXPORT>, C<@EXPORT_OK> and C<%EXPORT_TAGS> to decide
 what are exportable subroutines. It tries its best to implement
-a behavior akin to L<Exporter> without the corresponding package polution.
+a behavior akin to L<Exporter> without the corresponding namespace pollution.
 
 =head1 METHODS
 
